
.. If you created a package, create one automodule per module in the package.

.. automodule:: adafruit_featherwing.ina219_featherwing
   :members:

.. automodule:: adafruit_featherwing.joy_featherwing
   :members:

.. automodule:: adafruit_featherwing.alphanum_featherwing
   :members:

.. automodule:: adafruit_featherwing.dotstar_featherwing
   :members:

.. automodule:: adafruit_featherwing.neopixel_featherwing
   :members:

.. automodule:: adafruit_featherwing.rtc_featherwing
   :members:

.. automodule:: adafruit_featherwing.gps_featherwing
   :members:

.. automodule:: adafruit_featherwing.matrix_featherwing
   :members:

.. automodule:: adafruit_featherwing.minitft_featherwing
  :members:

.. automodule:: adafruit_featherwing.tempmotion_featherwing
  :members:
